==> haskell-pipes-4.3.16-215-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes
version:              4.3.16
visibility:           public
id:                   pipes-4.3.16-LZfhFcVjMzIBhB4624UE5U
key:                  pipes-4.3.16-LZfhFcVjMzIBhB4624UE5U
license:              BSD-3-Clause
copyright:            2012-2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components

    Advantages over traditional streaming libraries:

    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''

    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion

    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies

    * /Elegant semantics/: Use practical category theory

    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes

    * /Bidirectionality/: Implement duplex channels

    * /Extensive Documentation/: Second to none!

    Import "Pipes" to use the library.

    Read "Pipes.Tutorial" for an extensive tutorial.

category:             Control, Pipes
abi:                  54748f4e45f824ada531040e0e387f20
exposed:              True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial

import-dirs:          /usr/lib/ghc-9.4.8/site-local/pipes-4.3.16
library-dirs:         /usr/lib/ghc-9.4.8/site-local/pipes-4.3.16
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/pipes-4.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes
hs-libraries:         HSpipes-4.3.16-LZfhFcVjMzIBhB4624UE5U
depends:
    base-4.17.2.1 exceptions-0.10.5 mmorph-1.2.1-Dj3j5073UbJL5k7iF3E3ML
    mtl-2.2.2 transformers-0.5.6.2 void-0.7.3-H00KtmFLEBuFgBidznP5Pq

haddock-interfaces:   /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html:         /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-4.3.16-220-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pipes
version:              4.3.16
visibility:           public
id:                   pipes-4.3.16-C5wtPVlnu3DGanv76WOVKN
key:                  pipes-4.3.16-C5wtPVlnu3DGanv76WOVKN
license:              BSD-3-Clause
copyright:            2012-2016 Gabriel Gonzalez
maintainer:           Gabriel439@gmail.com
author:               Gabriel Gonzalez
synopsis:             Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components

    Advantages over traditional streaming libraries:

    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''

    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion

    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies

    * /Elegant semantics/: Use practical category theory

    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes

    * /Bidirectionality/: Implement duplex channels

    * /Extensive Documentation/: Second to none!

    Import "Pipes" to use the library.

    Read "Pipes.Tutorial" for an extensive tutorial.

category:             Control, Pipes
abi:                  b5f7b0b540a57d9bd5ca6c6076f542f8
exposed:              True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/pipes-4.3.16
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/pipes-4.3.16
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/pipes-4.3.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pipes
hs-libraries:         HSpipes-4.3.16-C5wtPVlnu3DGanv76WOVKN
depends:
    base-4.18.3.0 exceptions-0.10.7 mmorph-1.2.1-I2aM41LLh4IKelvS2bO760
    mtl-2.3.1 transformers-0.6.1.0 void-0.7.3-AAyPjWxpL8R2YjpUwnLovC

haddock-interfaces:   /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html:         /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
